@@ -1,3 +1,5 @@
+//! NcPlane constructors and ncplane_* static functions reimplementations
+
 // functions already exported by bindgen : 97
 // ------------------------------------------
 //  ncplane_above
@@ -160,14 +162,14 @@ use crate::{
     bindgen::__va_list_tag,
     cell_load, cell_release, cells_double_box, cells_rounded_box, channels_bchannel,
     channels_bg_alpha, channels_bg_default_p, channels_bg_rgb, channels_bg_rgb8, channels_fchannel,
-    channels_fg_alpha, channels_fg_default_p, channels_fg_rgb, channels_fg_rgb8, ncplane_at_cursor,
-    ncplane_at_yx, ncplane_box, ncplane_channels, ncplane_create, ncplane_cursor_move_yx,
-    ncplane_cursor_yx, ncplane_dim_yx, ncplane_gradient, ncplane_hline_interp, ncplane_putc_yx,
-    ncplane_putegc_yx, ncplane_putnstr_yx, ncplane_putstr_yx, ncplane_resize, ncplane_vline_interp,
-    ncplane_vprintf_yx, notcurses_align,
+    channels_fg_alpha, channels_fg_default_p, channels_fg_rgb, channels_fg_rgb8, ncpile_create,
+    ncplane_at_cursor, ncplane_at_yx, ncplane_box, ncplane_channels, ncplane_create,
+    ncplane_cursor_move_yx, ncplane_cursor_yx, ncplane_dim_yx, ncplane_gradient,
+    ncplane_hline_interp, ncplane_putc_yx, ncplane_putegc_yx, ncplane_putnstr_yx,
+    ncplane_putstr_yx, ncplane_resize, ncplane_vline_interp, ncplane_vprintf_yx, notcurses_align,
     types::{
-        AlphaBits, Cell, Channel, Channels, Color, EgcBackstop, IntResult, NcAlign,
-        NcPlane, NcPlaneOptions, StyleMask, NCPLANE_OPTION_HORALIGNED,
+        NcAlign, NcAlphaBits, NcCell, NcChannel, NcChannels, NcColor, NcPlane,
+        NcPlaneOptions, NcResult, NcStyleMask, Notcurses, NCPLANE_OPTION_HORALIGNED,
     },
 };
 
@@ -176,25 +178,19 @@ use crate::{
 impl NcPlaneOptions {
     /// `NcPlaneOptions` simple constructor with horizontal x
     pub fn new(y: i32, x: i32, rows: u32, cols: u32) -> Self {
-        Self::with_all_options(y, x, rows, cols, 0)
+        Self::with_flags(y, x, rows, cols, 0)
     }
 
     /// `NcPlaneOptions` simple constructor with horizontal alignment
     pub fn new_halign(y: i32, align: NcAlign, rows: u32, cols: u32) -> Self {
-        Self::with_all_options(
-            y,
-            align as i32,
-            rows,
-            cols,
-            NCPLANE_OPTION_HORALIGNED,
-        )
+        Self::with_flags(y, align as i32, rows, cols, NCPLANE_OPTION_HORALIGNED)
     }
 
     /// `NcplaneOptions` constructor
     ///
     /// Note: If you use`NCPLANE_OPTION_HORALIGNED` flag, you must provide
     /// the `NcAlign` value as the `x` parameter, casted to `i32`.
-    pub fn with_all_options(y: i32, x: i32, rows: u32, cols: u32, flags: u64) -> Self {
+    pub fn with_flags(y: i32, x: i32, rows: u32, cols: u32, flags: u64) -> Self {
         NcPlaneOptions {
             y,
             x,
@@ -213,6 +209,12 @@ impl NcPlane {
     pub unsafe fn new<'a>(bound_to: &mut NcPlane, options: &NcPlaneOptions) -> &'a mut NcPlane {
         &mut *ncplane_create(bound_to, options)
     }
+
+    /// `NcPlane` constructor.
+    /// The returned plane will be the top, bottom, and root of this new pile.
+    pub unsafe fn new_pile<'a>(nc: &mut Notcurses, options: &NcPlaneOptions) -> &'a mut NcPlane {
+        &mut *ncpile_create(nc, options)
+    }
 }
 
 // Static Functions ------------------------------------------------------------
@@ -230,12 +232,12 @@ pub fn ncplane_align(plane: &NcPlane, align: NcAlign, cols: i32) -> i32 {
 /// Retrieve the current contents of the cell under the cursor into 'cell'.
 /// This cell is invalidated if the associated plane is destroyed.
 #[inline]
-pub fn ncplane_at_cursor_cell(plane: &mut NcPlane, cell: &mut Cell) -> IntResult {
+pub fn ncplane_at_cursor_cell(plane: &mut NcPlane, cell: &mut NcCell) -> NcResult {
     let mut egc = unsafe { ncplane_at_cursor(plane, &mut cell.stylemask, &mut cell.channels) };
     if egc.is_null() {
         return -1;
     }
-    let result: IntResult = unsafe { cell_load(plane, cell, egc) };
+    let result: NcResult = unsafe { cell_load(plane, cell, egc) };
     if result < 0 {
         unsafe {
             free(&mut egc as *mut _ as *mut c_void);
@@ -247,13 +249,13 @@ pub fn ncplane_at_cursor_cell(plane: &mut NcPlane, cell: &mut Cell) -> IntResult
 /// Retrieve the current contents of the specified cell into 'cell'.
 /// This cell is invalidated if the associated plane is destroyed.
 #[inline]
-pub fn ncplane_at_yx_cell(plane: &mut NcPlane, y: i32, x: i32, cell: &mut Cell) -> IntResult {
+pub fn ncplane_at_yx_cell(plane: &mut NcPlane, y: i32, x: i32, cell: &mut NcCell) -> NcResult {
     let mut egc = unsafe { ncplane_at_yx(plane, y, x, &mut cell.stylemask, &mut cell.channels) };
     if egc.is_null() {
         return -1;
     }
     let channels = cell.channels; // need to preserve wide flag
-    let result: IntResult = unsafe { cell_load(plane, cell, egc) };
+    let result: NcResult = unsafe { cell_load(plane, cell, egc) };
     cell.channels = channels;
     unsafe {
         free(&mut egc as *mut _ as *mut c_void);
@@ -267,16 +269,16 @@ pub fn ncplane_at_yx_cell(plane: &mut NcPlane, y: i32, x: i32, cell: &mut Cell)
 #[inline]
 pub fn ncplane_box_sized(
     plane: &mut NcPlane,
-    ul: &Cell,
-    ur: &Cell,
-    ll: &Cell,
-    lr: &Cell,
-    hline: &Cell,
-    vline: &Cell,
+    ul: &NcCell,
+    ur: &NcCell,
+    ll: &NcCell,
+    lr: &NcCell,
+    hline: &NcCell,
+    vline: &NcCell,
     ylen: i32,
     xlen: i32,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     let (mut y, mut x) = (0, 0);
     unsafe {
         ncplane_cursor_yx(plane, &mut y, &mut x);
@@ -319,21 +321,21 @@ pub fn ncplane_dim_y(plane: &NcPlane) -> i32 {
 #[inline]
 pub fn ncplane_double_box(
     plane: &mut NcPlane,
-    stylemask: StyleMask,
-    channels: Channels,
+    stylemask: NcStyleMask,
+    channels: NcChannels,
     ystop: i32,
     xstop: i32,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     #[allow(unused_assignments)]
     let mut ret = 0;
 
-    let mut ul = cell_trivial_initializer![];
-    let mut ur = cell_trivial_initializer![];
-    let mut ll = cell_trivial_initializer![];
-    let mut lr = cell_trivial_initializer![];
-    let mut hl = cell_trivial_initializer![];
-    let mut vl = cell_trivial_initializer![];
+    let mut ul = NcCell::new_blank();
+    let mut ur = NcCell::new_blank();
+    let mut ll = NcCell::new_blank();
+    let mut lr = NcCell::new_blank();
+    let mut hl = NcCell::new_blank();
+    let mut vl = NcCell::new_blank();
 
     unsafe {
         ret = cells_double_box(
@@ -365,12 +367,12 @@ pub fn ncplane_double_box(
 #[inline]
 pub fn ncplane_double_box_sized(
     plane: &mut NcPlane,
-    stylemask: StyleMask,
-    channels: Channels,
+    stylemask: NcStyleMask,
+    channels: NcChannels,
     ylen: i32,
     xlen: i32,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     let (mut y, mut x) = (0, 0);
     unsafe {
         ncplane_cursor_yx(plane, &mut y, &mut x);
@@ -387,7 +389,7 @@ pub fn ncplane_double_box_sized(
 
 /// On error, return the negative number of cells drawn.
 #[inline]
-pub fn ncplane_hline(plane: &mut NcPlane, cell: &Cell, len: i32) -> i32 {
+pub fn ncplane_hline(plane: &mut NcPlane, cell: &NcCell, len: i32) -> i32 {
     unsafe { ncplane_hline_interp(plane, cell, len, cell.channels, cell.channels) }
 }
 
@@ -395,14 +397,14 @@ pub fn ncplane_hline(plane: &mut NcPlane, cell: &Cell, len: i32) -> i32 {
 #[inline]
 pub fn ncplane_perimeter(
     plane: &mut NcPlane,
-    ul: &Cell,
-    ur: &Cell,
-    ll: &Cell,
-    lr: &Cell,
-    hline: &Cell,
-    vline: &Cell,
+    ul: &NcCell,
+    ur: &NcCell,
+    ll: &NcCell,
+    lr: &NcCell,
+    hline: &NcCell,
+    vline: &NcCell,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     unsafe {
         ncplane_cursor_move_yx(plane, 0, 0);
         let (mut dimy, mut dimx) = (0, 0);
@@ -415,10 +417,10 @@ pub fn ncplane_perimeter(
 #[inline]
 pub fn ncplane_perimeter_double(
     plane: &mut NcPlane,
-    stylemask: StyleMask,
-    channels: Channels,
+    stylemask: NcStyleMask,
+    channels: NcChannels,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     if unsafe { ncplane_cursor_move_yx(plane, 0, 0) } != 0 {
         return -1;
     }
@@ -426,12 +428,12 @@ pub fn ncplane_perimeter_double(
     unsafe {
         ncplane_dim_yx(plane, &mut dimy, &mut dimx);
     }
-    let mut ul = cell_trivial_initializer![];
-    let mut ur = cell_trivial_initializer![];
-    let mut ll = cell_trivial_initializer![];
-    let mut lr = cell_trivial_initializer![];
-    let mut hl = cell_trivial_initializer![];
-    let mut vl = cell_trivial_initializer![];
+    let mut ul = NcCell::new_blank();
+    let mut ur = NcCell::new_blank();
+    let mut ll = NcCell::new_blank();
+    let mut lr = NcCell::new_blank();
+    let mut hl = NcCell::new_blank();
+    let mut vl = NcCell::new_blank();
     if unsafe {
         cells_double_box(
             plane,
@@ -464,10 +466,10 @@ pub fn ncplane_perimeter_double(
 #[inline]
 pub fn ncplane_perimeter_rounded(
     plane: &mut NcPlane,
-    stylemask: StyleMask,
-    channels: Channels,
+    stylemask: NcStyleMask,
+    channels: NcChannels,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     if unsafe { ncplane_cursor_move_yx(plane, 0, 0) } != 0 {
         return -1;
     }
@@ -475,12 +477,12 @@ pub fn ncplane_perimeter_rounded(
     unsafe {
         ncplane_dim_yx(plane, &mut dimy, &mut dimx);
     }
-    let mut ul = cell_trivial_initializer![];
-    let mut ur = cell_trivial_initializer![];
-    let mut ll = cell_trivial_initializer![];
-    let mut lr = cell_trivial_initializer![];
-    let mut hl = cell_trivial_initializer![];
-    let mut vl = cell_trivial_initializer![];
+    let mut ul = NcCell::new_blank();
+    let mut ur = NcCell::new_blank();
+    let mut ll = NcCell::new_blank();
+    let mut lr = NcCell::new_blank();
+    let mut hl = NcCell::new_blank();
+    let mut vl = NcCell::new_blank();
     if unsafe {
         cells_rounded_box(
             plane,
@@ -511,19 +513,19 @@ pub fn ncplane_perimeter_rounded(
 
 /// Call ncplane_putc_yx() for the current cursor location.
 #[inline]
-pub fn ncplane_putc(plane: &mut NcPlane, cell: &Cell) -> IntResult {
+pub fn ncplane_putc(plane: &mut NcPlane, cell: &NcCell) -> NcResult {
     unsafe { ncplane_putc_yx(plane, -1, -1, cell) }
 }
 
 /// Call ncplane_putegc() at the current cursor location.
 #[inline]
-pub fn ncplane_putegc(plane: &mut NcPlane, gcluster: i8, sbytes: &mut i32) -> IntResult {
+pub fn ncplane_putegc(plane: &mut NcPlane, gcluster: i8, sbytes: &mut i32) -> NcResult {
     unsafe { ncplane_putegc_yx(plane, -1, -1, &gcluster, sbytes) }
 }
 
 ///
 #[inline]
-pub fn ncplane_putstr(plane: &mut NcPlane, gclustarr: &[u8]) -> IntResult {
+pub fn ncplane_putstr(plane: &mut NcPlane, gclustarr: &[u8]) -> NcResult {
     unsafe {
         ncplane_putstr_yx(
             plane,
@@ -536,7 +538,7 @@ pub fn ncplane_putstr(plane: &mut NcPlane, gclustarr: &[u8]) -> IntResult {
 
 ///
 #[inline]
-pub fn ncplane_putnstr(plane: &mut NcPlane, size: u64, gclustarr: &[u8]) -> IntResult {
+pub fn ncplane_putnstr(plane: &mut NcPlane, size: u64, gclustarr: &[u8]) -> NcResult {
     unsafe {
         ncplane_putnstr_yx(
             plane,
@@ -551,7 +553,7 @@ pub fn ncplane_putnstr(plane: &mut NcPlane, size: u64, gclustarr: &[u8]) -> IntR
 /// Resize the plane, retaining what data we can (everything, unless we're
 /// shrinking in some dimension). Keep the origin where it is.
 #[inline]
-pub fn ncplane_resize_simple(plane: &mut NcPlane, ylen: i32, xlen: i32) -> IntResult {
+pub fn ncplane_resize_simple(plane: &mut NcPlane, ylen: i32, xlen: i32) -> NcResult {
     let (mut oldy, mut oldx) = (0, 0);
     unsafe {
         ncplane_dim_yx(plane, &mut oldy, &mut oldx);
@@ -576,13 +578,13 @@ pub fn ncplane_resize_simple(plane: &mut NcPlane, ylen: i32, xlen: i32) -> IntRe
 ///
 /// On error, return the negative number of cells drawn.
 #[inline]
-pub fn ncplane_vline(plane: &mut NcPlane, cell: &Cell, len: i32) -> i32 {
+pub fn ncplane_vline(plane: &mut NcPlane, cell: &NcCell, len: i32) -> i32 {
     unsafe { ncplane_vline_interp(plane, cell, len, cell.channels, cell.channels) }
 }
 
 ///
 #[inline]
-pub fn ncplane_vprintf(plane: &mut NcPlane, format: &str, ap: &mut __va_list_tag) -> IntResult {
+pub fn ncplane_vprintf(plane: &mut NcPlane, format: &str, ap: &mut __va_list_tag) -> NcResult {
     unsafe {
         ncplane_vprintf_yx(
             plane,
@@ -602,14 +604,14 @@ pub fn ncplane_vprintf(plane: &mut NcPlane, format: &str, ap: &mut __va_list_tag
 pub fn ncplane_gradient_sized(
     plane: &mut NcPlane,
     egc: &[u8],
-    stylemask: StyleMask,
+    stylemask: NcStyleMask,
     ul: u64,
     ur: u64,
     ll: u64,
     lr: u64,
     ylen: i32,
     xlen: i32,
-) -> IntResult {
+) -> NcResult {
     if ylen < 1 || xlen < 1 {
         return -1;
     }
@@ -632,37 +634,37 @@ pub fn ncplane_gradient_sized(
 
 /// Extract the 32-bit working foreground channel from an ncplane.
 #[inline]
-pub fn ncplane_fchannel(plane: &NcPlane) -> Channel {
+pub fn ncplane_fchannel(plane: &NcPlane) -> NcChannel {
     channels_fchannel(unsafe { ncplane_channels(plane) })
 }
 
 /// Extract the 32-bit working background channel from an ncplane.
 #[inline]
-pub fn ncplane_bchannel(plane: &NcPlane) -> Channel {
+pub fn ncplane_bchannel(plane: &NcPlane) -> NcChannel {
     channels_bchannel(unsafe { ncplane_channels(plane) })
 }
 
 /// Extract 24 bits of working foreground RGB from an ncplane, shifted to LSBs.
 #[inline]
-pub fn ncplane_fg_rgb(plane: &NcPlane) -> Channel {
+pub fn ncplane_fg_rgb(plane: &NcPlane) -> NcChannel {
     channels_fg_rgb(unsafe { ncplane_channels(plane) })
 }
 
 /// Extract 24 bits of working background RGB from an ncplane, shifted to LSBs.
 #[inline]
-pub fn ncplane_bg_rgb(plane: &NcPlane) -> Channel {
+pub fn ncplane_bg_rgb(plane: &NcPlane) -> NcChannel {
     channels_bg_rgb(unsafe { ncplane_channels(plane) })
 }
 
 /// Extract 2 bits of foreground alpha from 'struct ncplane', shifted to LSBs.
 #[inline]
-pub fn ncplane_fg_alpha(plane: &NcPlane) -> AlphaBits {
+pub fn ncplane_fg_alpha(plane: &NcPlane) -> NcAlphaBits {
     channels_fg_alpha(unsafe { ncplane_channels(plane) })
 }
 
 /// Extract 2 bits of background alpha from 'struct ncplane', shifted to LSBs.
 #[inline]
-pub fn ncplane_bg_alpha(plane: &NcPlane) -> AlphaBits {
+pub fn ncplane_bg_alpha(plane: &NcPlane) -> NcAlphaBits {
     channels_bg_alpha(unsafe { ncplane_channels(plane) })
 }
 
@@ -682,10 +684,10 @@ pub fn ncplane_bg_default_p(plane: &NcPlane) -> bool {
 #[inline]
 pub fn ncplane_fg_rgb8(
     plane: &NcPlane,
-    red: &mut Color,
-    green: &mut Color,
-    blue: &mut Color,
-) -> Channel {
+    red: &mut NcColor,
+    green: &mut NcColor,
+    blue: &mut NcColor,
+) -> NcChannel {
     channels_fg_rgb8(unsafe { ncplane_channels(plane) }, red, green, blue)
 }
 
@@ -693,10 +695,10 @@ pub fn ncplane_fg_rgb8(
 #[inline]
 pub fn ncplane_bg_rgb8(
     plane: &NcPlane,
-    red: &mut Color,
-    green: &mut Color,
-    blue: &mut Color,
-) -> Channel {
+    red: &mut NcColor,
+    green: &mut NcColor,
+    blue: &mut NcColor,
+) -> NcChannel {
     channels_bg_rgb8(unsafe { ncplane_channels(plane) }, red, green, blue)
 }
 
@@ -704,21 +706,21 @@ pub fn ncplane_bg_rgb8(
 #[inline]
 pub fn ncplane_rounded_box(
     plane: &mut NcPlane,
-    stylemask: StyleMask,
-    channels: Channels,
+    stylemask: NcStyleMask,
+    channels: NcChannels,
     ystop: i32,
     xstop: i32,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     #[allow(unused_assignments)]
     let mut ret = 0;
 
-    let mut ul = cell_trivial_initializer![];
-    let mut ur = cell_trivial_initializer![];
-    let mut ll = cell_trivial_initializer![];
-    let mut lr = cell_trivial_initializer![];
-    let mut hl = cell_trivial_initializer![];
-    let mut vl = cell_trivial_initializer![];
+    let mut ul = NcCell::new_blank();
+    let mut ur = NcCell::new_blank();
+    let mut ll = NcCell::new_blank();
+    let mut lr = NcCell::new_blank();
+    let mut hl = NcCell::new_blank();
+    let mut vl = NcCell::new_blank();
 
     unsafe {
         ret = cells_rounded_box(
@@ -750,12 +752,12 @@ pub fn ncplane_rounded_box(
 #[inline]
 pub fn ncplane_rounded_box_sized(
     plane: &mut NcPlane,
-    stylemask: StyleMask,
-    channels: Channels,
+    stylemask: NcStyleMask,
+    channels: NcChannels,
     ylen: i32,
     xlen: i32,
     ctlword: u32,
-) -> IntResult {
+) -> NcResult {
     let (mut y, mut x) = (0, 0);
     unsafe {
         ncplane_cursor_yx(plane, &mut y, &mut x);
