@@ -195,7 +195,13 @@ ncreel_demo_core(struct notcurses* nc){
   int x = 8, y = 4;
   int dimy, dimx;
   struct ncplane* std = notcurses_stddim_yx(nc, &dimy, &dimx);
-  struct ncplane* n = ncplane_new(std, dimy - 12, dimx - 16, y, x, NULL, NULL);
+  struct ncplane_options nopts = {
+    .y = y,
+    .x = x,
+    .rows = dimy - 12,
+    .cols = dimx - 16,
+  };
+  struct ncplane* n = ncplane_create(std, &nopts);
   if(n == NULL){
     return -1;
   }
