@@ -32,9 +32,7 @@ legend(struct notcurses* nc, const char* msg){
     .rows = 3,
     .cols = strlen(msg) + 4,
     .y = 3,
-    .horiz = {
-      .align = NCALIGN_CENTER,
-    },
+    .x = NCALIGN_CENTER,
     .flags = NCPLANE_OPTION_HORALIGNED,
   };
   struct ncplane* n = ncplane_create(notcurses_stdplane(nc), &nopts);
@@ -110,7 +108,13 @@ slidepanel(struct notcurses* nc, struct ncplane* stdn){
   struct ncplane* l;
 
   // First we just create a plane with no styling and no glyphs.
-  struct ncplane* n = ncplane_new(stdn, ny, nx, yoff, xoff, NULL, NULL);
+  struct ncplane_options nopts = {
+    .y = yoff,
+    .x = xoff,
+    .rows = ny,
+    .cols = nx,
+  };
+  struct ncplane* n = ncplane_create(stdn, &nopts);
 
   // Zero-initialized channels use the default color, opaquely. Since we have
   // no glyph, we should show underlying glyphs in the default colors. The
