@@ -1,19 +1,17 @@
 #include "internal.h"
 
-void notcurses_debug(notcurses* nc, FILE* debugfp){
-  const ncplane* n = nc->top;
+static void
+ncpile_debug(const ncpile* p, FILE* debugfp){
+  fprintf(debugfp, "  -=+********************** %16p pile *************************+=-\n", p);
+  const ncplane* n = p->top;
   const ncplane* prev = NULL;
   int planeidx = 0;
-  fprintf(debugfp, " ************************** notcurses debug state *****************************\n");
   while(n){
     fprintf(debugfp, "%04d off y: %3d x: %3d geom y: %3d x: %3d curs y: %3d x: %3d %p %.8s\n",
             planeidx, n->absy, n->absx, n->leny, n->lenx, n->y, n->x, n, n->name);
     if(n->boundto || n->bnext || n->bprev || n->blist){
-      fprintf(debugfp, " bound %p → %p ← %p binds %p\n",
-              n->boundto, n->bnext, n->bprev, n->blist);
-    }
-    if(n->bnext == n || (n->boundto == n && n != nc->stdplane) || n->blist == n){
-      fprintf(debugfp, "WARNING: bound pointers target self\n");
+      fprintf(debugfp, " bound %p ← %p → %p binds %p\n",
+              n->boundto, n->bprev, n->bnext, n->blist);
     }
     if(n->bprev && (*n->bprev != n)){
       fprintf(stderr, " WARNING: expected *->bprev %p, got %p\n", n, *n->bprev);
@@ -21,12 +19,29 @@ void notcurses_debug(notcurses* nc, FILE* debugfp){
     if(n->above != prev){
       fprintf(stderr, " WARNING: expected ->above %p, got %p\n", prev, n->above);
     }
+    if(ncplane_pile_const(n) != p){
+      fprintf(stderr, " WARNING: expected pile %p, got %p\n", p, ncplane_pile_const(n));
+    }
     prev = n;
     n = n->below;
     ++planeidx;
   }
-  if(nc->bottom != prev){
-    fprintf(stderr, " WARNING: expected ->bottom %p, got %p\n", prev, nc->bottom);
+  if(p->bottom != prev){
+    fprintf(stderr, " WARNING: expected ->bottom %p, got %p\n", prev, p->bottom);
   }
+}
+
+void notcurses_debug(notcurses* nc, FILE* debugfp){
+  const ncpile* p = ncplane_pile(nc->stdplane);
+  fprintf(debugfp, " ************************** notcurses debug state *****************************\n");
+  const ncpile* p0 = p;
+  do{
+    ncpile_debug(p0, debugfp);
+    const ncpile* prev = p0;
+    p0 = p0->next;
+    if(p0->prev != prev){
+      fprintf(stderr, "WARNING: expected ->prev %p, got %p\n", prev, p0->prev);
+    }
+  }while(p != p0);
   fprintf(debugfp, " ******************************************************************************\n");
 }
