@@ -1,4 +1,4 @@
-#include "version.h"
+#include "builddef.h"
 #ifdef USE_FFMPEG
 #include "ffmpeg.h"
 #include "internal.h"
@@ -348,6 +348,9 @@ int ncvisual_stream(notcurses* nc, ncvisual* ncv, float timescale,
     if(frame == 1 && ts){
       usets = true;
     }
+    if(activevopts.n){
+      ncplane_erase(activevopts.n); // new frame could be partially transparent
+    }
     if((newn = ncvisual_render(nc, ncv, &activevopts)) == NULL){
       if(activevopts.n != vopts->n){
         ncplane_destroy(activevopts.n);
@@ -394,6 +397,20 @@ int ncvisual_stream(notcurses* nc, ncvisual* ncv, float timescale,
   return ncerr;
 }
 
+int ncvisual_decode_loop(ncvisual* ncv){
+  int r = ncvisual_decode(ncv);
+  if(r == 1){
+    if(av_seek_frame(ncv->details.fmtctx, ncv->details.stream_index, 0, AVSEEK_FLAG_FRAME) < 0){
+      // FIXME log error
+      return -1;
+    }
+    if(ncvisual_decode(ncv) < 0){
+      return -1;
+    }
+  }
+  return r;
+}
+
 int ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
                   const struct blitset* bset, int placey, int placex,
                   int begy, int begx, int leny, int lenx,
@@ -451,7 +468,7 @@ int ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
   }
 //fprintf(stderr, "place: %d/%d rows/cols: %d/%d %d/%d+%d/%d\n", placey, placex, rows, cols, begy, begx, leny, lenx);
   if(rgba_blit_dispatch(n, bset, placey, placex, stride, data, begy, begx,
-                        leny, lenx, blendcolors) <= 0){
+                        leny, lenx, blendcolors) < 0){
 //fprintf(stderr, "rgba dispatch failed!\n");
     if(sframe){
       av_freep(sframe->data);
