@@ -185,6 +185,7 @@ dup_menu_sections(ncmenu* ncm, const ncmenu_options* opts, int* totalwidth, int*
       ncm->sections[i].bodycols = 0;
       ncm->sections[i].itemselected = -1;
       ncm->sections[i].shortcut_offset = -1;
+      ncm->sections[i].enabled_item_count = 0;
     }
   }
   if(ncm->sectioncount == 1 && rightaligned){
@@ -305,7 +306,7 @@ ncmenu* ncmenu_create(ncplane* n, const ncmenu_options* opts){
     return NULL;
   }
   if(opts->flags > NCMENU_OPTION_HIDING){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016lx\n", opts->flags);
+    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   int totalheight = 1;
   int totalwidth = 2; // start with two-character margin on the left
