@@ -24,9 +24,9 @@
 #define ESC "\x1b"
 
 void notcurses_version_components(int* major, int* minor, int* patch, int* tweak){
-  *major = atoi(NOTCURSES_VERSION_MAJOR);
-  *minor = atoi(NOTCURSES_VERSION_MINOR);
-  *patch = atoi(NOTCURSES_VERSION_PATCH);
+  *major = NOTCURSES_VERNUM_MAJOR;
+  *minor = NOTCURSES_VERNUM_MINOR;
+  *patch = NOTCURSES_VERNUM_PATCH;
   *tweak = atoi(NOTCURSES_VERSION_TWEAK);
 }
 
@@ -229,12 +229,6 @@ char* ncplane_at_yx(const ncplane* n, int y, int x, uint16_t* stylemask, uint64_
   return ret;
 }
 
-cell* ncplane_cell_ref_yx(ncplane* n, int y, int x){
-  assert(y < n->leny);
-  assert(x < n->lenx);
-  return &n->fb[nfbcellidx(n, y, x)];
-}
-
 void ncplane_dim_yx(const ncplane* n, int* rows, int* cols){
   if(rows){
     *rows = n->leny;
@@ -271,12 +265,29 @@ int update_term_dimensions(int fd, int* rows, int* cols){
   return 0;
 }
 
+// destroy an empty ncpile. only call with pilelock held.
+static void
+ncpile_destroy(ncpile* pile){
+  if(pile){
+    pile->prev->next = pile->next;
+    pile->next->prev = pile->prev;
+    free(pile->crender);
+    free(pile);
+  }
+}
+
 void free_plane(ncplane* p){
   if(p){
-    // ncdirect fakes an ncplane with no ->nc
-    if(ncplane_notcurses(p)){
+    // ncdirect fakes an ncplane with no ->pile
+    if(ncplane_pile(p)){
       --ncplane_notcurses(p)->stats.planes;
       ncplane_notcurses(p)->stats.fbbytes -= sizeof(*p->fb) * p->leny * p->lenx;
+      if(p->above == NULL && p->below == NULL){
+        struct notcurses* nc = ncplane_notcurses(p);
+        pthread_mutex_lock(&nc->pilelock);
+        ncpile_destroy(ncplane_pile(p));
+        pthread_mutex_unlock(&nc->pilelock);
+      }
     }
     egcpool_dump(&p->pool);
     free(p->name);
@@ -285,19 +296,48 @@ void free_plane(ncplane* p){
   }
 }
 
+// create a new ncpile. only call with pilelock held.
+static ncpile*
+make_ncpile(notcurses* nc, ncplane* n){
+  ncpile* ret = malloc(sizeof(*ret));
+  if(ret){
+    ret->nc = nc;
+    ret->top = n;
+    ret->bottom = n;
+    if(nc->stdplane){
+      ret->prev = ncplane_pile(nc->stdplane)->prev;
+      ncplane_pile(nc->stdplane)->prev->next = ret;
+      ret->next = ncplane_pile(nc->stdplane);
+      ncplane_pile(nc->stdplane)->prev = ret;
+    }else{
+      ret->prev = ret;
+      ret->next = ret;
+    }
+    n->pile = ret;
+    n->above = NULL;
+    n->below = NULL;
+    ret->crenderlen = 0;
+    ret->crender = NULL;
+  }
+  return ret;
+}
+
 // create a new ncplane at the specified location (relative to the true screen,
 // having origin at 0,0), having the specified size, and put it at the top of
 // the planestack. its cursor starts at its origin; its style starts as null.
 // a plane may exceed the boundaries of the screen, but must have positive
-// size in both dimensions. bind the plane to 'n', which may be NULL. if bound
-// to a plane, this plane moves when that plane moves, and move targets are
-// relative to that plane.
-// there's a denormalized case we also must handle, that of the "fake" isolated
-// ncplane created by ncdirect for rendering visuals. in that case (and only in
-// that case), nc is NULL.
-ncplane* ncplane_new_internal(notcurses* nc, ncplane* n, const ncplane_options* nopts){
+// size in both dimensions. bind the plane to 'n', which may be NULL to create
+// a new pile. if bound to a plane instead, this plane moves when that plane
+// moves, and coordinates to move to are relative to that plane.
+// there are two denormalized case we also must handle, that of the "fake"
+// isolated ncplane created by ncdirect for rendering visuals. in that case
+// (and only in that case), nc is NULL (as is n). there's also creation of the
+// initial standard plane, in which case nc is not NULL, but nc->stdplane *is*
+// (as once more is n).
+ncplane* ncplane_new_internal(notcurses* nc, ncplane* n,
+                              const ncplane_options* nopts){
   if(nopts->flags > NCPLANE_OPTION_HORALIGNED){
-    logwarn(nc, "Provided unsupported flags %016lx\n", nopts->flags);
+    logwarn(nc, "Provided unsupported flags %016jx\n", (uintmax_t)nopts->flags);
   }
   if(nopts->rows <= 0 || nopts->cols <= 0){
     logerror(nc, "Won't create denormalized plane (r=%d, c=%d)\n",
@@ -321,12 +361,20 @@ ncplane* ncplane_new_internal(notcurses* nc, ncplane* n, const ncplane_options*
   p->blist = NULL;
   p->name = strdup(nopts->name ? nopts->name : "");
   p->align = NCALIGN_UNALIGNED;
-  if( (p->boundto = n) ){
+  if(!n){ // new root/standard plane
+    p->absy = nopts->y;
+    p->absx = nopts->x;
+    p->bnext = NULL;
+    p->bprev = NULL;
+    p->boundto = p;
+    p->align = NCALIGN_UNALIGNED;
+  }else{ // bound to preexisting pile
     if(nopts->flags & NCPLANE_OPTION_HORALIGNED){
       p->absx = ncplane_align(n, nopts->x, nopts->cols);
       p->align = nopts->x;
     }else{
       p->absx = nopts->x;
+      p->align = NCALIGN_UNALIGNED;
     }
     p->absx += n->absx;
     p->absy = nopts->y + n->absy;
@@ -335,15 +383,7 @@ ncplane* ncplane_new_internal(notcurses* nc, ncplane* n, const ncplane_options*
     }
     p->bprev = &n->blist;
     *p->bprev = p;
-  }else{ // new standard plane
-    assert(!(nopts->flags & NCPLANE_OPTION_HORALIGNED));
-    assert(0 == nopts->y);
-    assert(0 == nopts->x);
-    p->absx = (nc ? nc->margin_l : 0);
-    p->absy = (nc ? nc->margin_t : 0);
-    p->bnext = NULL;
-    p->bprev = NULL;
-    p->boundto = p;
+    p->boundto = n;
   }
   p->resizecb = nopts->resizecb;
   p->stylemask = 0;
@@ -351,18 +391,27 @@ ncplane* ncplane_new_internal(notcurses* nc, ncplane* n, const ncplane_options*
   egcpool_init(&p->pool);
   cell_init(&p->basecell);
   p->userptr = nopts->userptr;
-  p->above = NULL;
-  if( (p->nc = nc) ){ // every plane has a notcurses object
-    if( (p->below = nc->top) ){ // always happens save initial plane
-      nc->top->above = p;
-    }else{
-      nc->bottom = p;
+  if(nc == NULL){ // fake ncplane backing ncdirect object
+    p->above = NULL;
+    p->below = NULL;
+    p->pile = NULL;
+  }else{
+    pthread_mutex_lock(&nc->pilelock);
+    ncpile* pile = n ? ncplane_pile(n) : NULL;
+    if( (p->pile = pile) ){ // existing pile
+      p->above = NULL;
+      if( (p->below = pile->top) ){ // always happens save initial plane
+        pile->top->above = p;
+      }else{
+        pile->bottom = p;
+      }
+      pile->top = p;
+    }else{ // new pile
+      make_ncpile(nc, p);
     }
-    nc->top = p;
     nc->stats.fbbytes += fbsize;
     ++nc->stats.planes;
-  }else{ // fake ncplane backing ncdirect object
-    p->below = NULL;
+    pthread_mutex_unlock(&nc->pilelock);
   }
   loginfo(nc, "Created new %dx%d plane \"%s\" @ %dx%d\n",
           nopts->rows, nopts->cols, p->name, p->absy, p->absx);
@@ -371,11 +420,12 @@ ncplane* ncplane_new_internal(notcurses* nc, ncplane* n, const ncplane_options*
 
 // create an ncplane of the specified dimensions, but do not yet place it in
 // the z-buffer. clear out all cells. this is for a wholly new context.
+// FIXME set up using resizecb rather than special-purpose from SIGWINCH
 static ncplane*
 create_initial_ncplane(notcurses* nc, int dimy, int dimx){
   ncplane_options nopts = {
-    .y = 0,
-    .x = 0,
+    .y = nc->margin_t,
+    .x = nc->margin_l,
     .rows = dimy - (nc->margin_t + nc->margin_b),
     .cols = dimx - (nc->margin_l + nc->margin_r),
     .name = "std",
@@ -395,6 +445,10 @@ ncplane* ncplane_create(ncplane* n, const ncplane_options* nopts){
   return ncplane_new_internal(ncplane_notcurses(n), n, nopts);
 }
 
+ncplane* ncpile_create(notcurses* nc, const struct ncplane_options* nopts){
+  return ncplane_new_internal(nc, NULL, nopts);
+}
+
 struct ncplane* ncplane_new(struct ncplane* n, int rows, int cols, int y, int x, void* opaque, const char* name){
   ncplane_options nopts = {
     .y = y,
@@ -620,12 +674,12 @@ int ncplane_destroy(ncplane* ncp){
   if(ncp->above){
     ncp->above->below = ncp->below;
   }else{
-    ncplane_notcurses(ncp)->top = ncp->below;
+    ncplane_pile(ncp)->top = ncp->below;
   }
   if(ncp->below){
     ncp->below->above = ncp->above;
   }else{
-    ncplane_notcurses(ncp)->bottom = ncp->above;
+    ncplane_pile(ncp)->bottom = ncp->above;
   }
   if(ncp->bprev){
     if( (*ncp->bprev = ncp->bnext) ){
@@ -761,12 +815,22 @@ init_banner(const notcurses* nc){
     printf("\n notcurses %s by nick black et al", notcurses_version());
     term_fg_palindex(nc, stdout, nc->tcache.colors <= 256 ? 12 % nc->tcache.colors : 0x2080e0);
     printf("\n  %d rows %d cols (%sB) %zuB cells %d colors%s\n"
-           "  compiled with gcc-%s\n"
+           "  compiled with gcc-%s, %s-endian\n"
            "  terminfo from %s\n",
            nc->stdplane->leny, nc->stdplane->lenx,
            bprefix(nc->stats.fbbytes, 1, prefixbuf, 0), sizeof(cell),
            nc->tcache.colors, nc->tcache.RGBflag ? "+RGB" : "",
-           __VERSION__, curses_version());
+           __VERSION__,
+#ifdef __BYTE_ORDER__
+#if __BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__
+           "little"
+#else
+           "big"
+#endif
+#else
+#error "No __BYTE_ORDER__ definition"
+#endif
+           , curses_version());
 #ifdef USE_FFMPEG
     printf("  avformat %u.%u.%u avutil %u.%u.%u swscale %u.%u.%u\n",
           LIBAVFORMAT_VERSION_MAJOR, LIBAVFORMAT_VERSION_MINOR, LIBAVFORMAT_VERSION_MICRO,
@@ -886,6 +950,30 @@ int ncinputlayer_init(ncinputlayer* nilayer, FILE* infp){
   return 0;
 }
 
+// initialize a recursive mutex lock in a way that works on both glibc + musl
+int recursive_lock_init(pthread_mutex_t *lock){
+#ifndef __GLIBC__
+#define PTHREAD_MUTEX_RECURSIVE_NP PTHREAD_MUTEX_RECURSIVE
+#endif
+  pthread_mutexattr_t attr;
+  if(pthread_mutexattr_init(&attr)){
+    return -1;
+  }
+  if(pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE_NP)){
+    pthread_mutexattr_destroy(&attr);
+    return -1;
+  }
+  if(pthread_mutex_init(lock, &attr)){
+    pthread_mutexattr_destroy(&attr);
+    return -1;
+  }
+  pthread_mutexattr_destroy(&attr);
+  return 0;
+#ifndef __GLIBC__
+#undef PTHREAD_MUTEX_RECURSIVE_NP
+#endif
+}
+
 notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   notcurses_options defaultopts;
   memset(&defaultopts, 0, sizeof(defaultopts));
@@ -897,7 +985,7 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
     return NULL;
   }
   if(opts->flags >= (NCOPTION_NO_FONT_CHANGES << 1u)){
-    fprintf(stderr, "Warning: unknown Notcurses options %016lx\n", opts->flags);
+    fprintf(stderr, "Warning: unknown Notcurses options %016jx\n", (uintmax_t)opts->flags);
   }
   notcurses* ret = malloc(sizeof(*ret));
   if(ret == NULL){
@@ -921,6 +1009,11 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   if(outfp == NULL){
     outfp = stdout;
   }
+  if(recursive_lock_init(&ret->pilelock)){
+    fprintf(stderr, "Couldn't initialize pile mutex\n");
+    free(ret);
+    return NULL;
+  }
   ret->margin_t = opts->margin_t;
   ret->margin_b = opts->margin_b;
   ret->margin_l = opts->margin_l;
@@ -1002,25 +1095,25 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
     terminfostr(&ret->tcache.smcup, "smcup");
     terminfostr(&ret->tcache.rmcup, "rmcup");
   }
-  ret->bottom = ret->top = ret->stdplane = NULL;
   if(ncvisual_init(ffmpeg_log_level(ret->loglevel))){
     goto err;
   }
+  ret->stdplane = NULL;
   if((ret->stdplane = create_initial_ncplane(ret, dimy, dimx)) == NULL){
     goto err;
   }
   if(ret->ttyfd >= 0){
     if(ret->tcache.smkx && tty_emit("smkx", ret->tcache.smkx, ret->ttyfd)){
-      free_plane(ret->top);
+      free_plane(ret->stdplane);
       goto err;
     }
     if(ret->tcache.civis && tty_emit("civis", ret->tcache.civis, ret->ttyfd)){
-      free_plane(ret->top);
+      free_plane(ret->stdplane);
       goto err;
     }
   }
   if((ret->rstate.mstreamfp = open_memstream(&ret->rstate.mstream, &ret->rstate.mstrsize)) == NULL){
-    free_plane(ret->top);
+    free_plane(ret->stdplane);
     goto err;
   }
   ret->rstate.x = ret->rstate.y = -1;
@@ -1029,7 +1122,7 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   if(ret->ttyfd >= 0){
     if(ret->tcache.smcup){
       if(tty_emit("smcup", ret->tcache.smcup, ret->ttyfd)){
-        free_plane(ret->top);
+        free_plane(ret->stdplane);
         goto err;
       }
       // explicit clear even though smcup *might* clear
@@ -1048,6 +1141,7 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   return ret;
 
 err:
+  fprintf(stderr, "Alas, you will not be going to space today.\n");
   // FIXME looks like we have some memory leaks on this error path?
   tcsetattr(ret->ttyfd, TCSANOW, &ret->tpreserved);
   drop_signals(ret);
@@ -1055,8 +1149,11 @@ err:
   return NULL;
 }
 
-void notcurses_drop_planes(notcurses* nc){
-  ncplane* p = nc->top;
+// updates *pile to point at (*pile)->next, frees all but standard pile/plane
+static void
+ncpile_drop(notcurses* nc, ncpile** pile){
+  ncpile* next = (*pile)->next;
+  ncplane* p = (*pile)->top;
   while(p){
     ncplane* tmp = p->below;
     if(nc->stdplane != p){
@@ -1064,7 +1161,20 @@ void notcurses_drop_planes(notcurses* nc){
     }
     p = tmp;
   }
-  nc->top = nc->bottom = nc->stdplane;
+  *pile = next;
+}
+
+// drop all piles and all planes, save the standard plane and its pile
+void notcurses_drop_planes(notcurses* nc){
+  pthread_mutex_lock(&nc->pilelock);
+  ncpile* p = ncplane_pile(nc->stdplane);
+  ncpile* p0 = p;
+  do{
+    ncpile_drop(nc, &p);
+  }while(p0 != p);
+  pthread_mutex_unlock(&nc->pilelock);
+  ncplane_pile(nc->stdplane)->top = nc->stdplane;
+  ncplane_pile(nc->stdplane)->bottom = nc->stdplane;
   nc->stdplane->above = nc->stdplane->below = NULL;
 }
 
@@ -1072,10 +1182,9 @@ int notcurses_stop(notcurses* nc){
   int ret = 0;
   if(nc){
     ret |= notcurses_stop_minimal(nc);
-    while(nc->top){
-      ncplane* p = nc->top->below;
-      free_plane(nc->top);
-      nc->top = p;
+    if(nc->stdplane){
+      notcurses_drop_planes(nc);
+      free_plane(nc->stdplane);
     }
     if(nc->rstate.mstreamfp){
       fclose(nc->rstate.mstreamfp);
@@ -1135,6 +1244,7 @@ int notcurses_stop(notcurses* nc){
       }
     }
     del_curterm(cur_term);
+    ret |= pthread_mutex_destroy(&nc->pilelock);
     free(nc);
   }
   return ret;
@@ -1248,22 +1358,25 @@ int ncplane_move_above(ncplane* restrict n, ncplane* restrict above){
   if(n == above){
     return -1;
   }
+  if(ncplane_pile(n) != ncplane_pile(above)){ // can't move among piles
+    return -1;
+  }
   if(n->below != above){
     // splice out 'n'
     if(n->below){
       n->below->above = n->above;
     }else{
-      ncplane_notcurses(n)->bottom = n->above;
+      ncplane_pile(n)->bottom = n->above;
     }
     if(n->above){
       n->above->below = n->below;
     }else{
-      ncplane_notcurses(n)->top = n->below;
+      ncplane_pile(n)->top = n->below;
     }
     if( (n->above = above->above) ){
       above->above->below = n;
     }else{
-      ncplane_notcurses(n)->top = n;
+      ncplane_pile(n)->top = n;
     }
     above->above = n;
     n->below = above;
@@ -1276,21 +1389,24 @@ int ncplane_move_below(ncplane* restrict n, ncplane* restrict below){
   if(n == below){
     return -1;
   }
+  if(ncplane_pile(n) != ncplane_pile(below)){ // can't move among piles
+    return -1;
+  }
   if(n->above != below){
     if(n->below){
       n->below->above = n->above;
     }else{
-      ncplane_notcurses(n)->bottom = n->above;
+      ncplane_pile(n)->bottom = n->above;
     }
     if(n->above){
       n->above->below = n->below;
     }else{
-      ncplane_notcurses(n)->top = n->below;
+      ncplane_pile(n)->top = n->below;
     }
     if( (n->below = below->below) ){
       below->below->above = n;
     }else{
-      ncplane_notcurses(n)->bottom = n;
+      ncplane_pile(n)->bottom = n;
     }
     below->below = n;
     n->above = below;
@@ -1303,13 +1419,13 @@ void ncplane_move_top(ncplane* n){
     if( (n->above->below = n->below) ){
       n->below->above = n->above;
     }else{
-      ncplane_notcurses(n)->bottom = n->above;
+      ncplane_pile(n)->bottom = n->above;
     }
     n->above = NULL;
-    if( (n->below = ncplane_notcurses(n)->top) ){
+    if( (n->below = ncplane_pile(n)->top) ){
       n->below->above = n;
     }
-    ncplane_notcurses(n)->top = n;
+    ncplane_pile(n)->top = n;
   }
 }
 
@@ -1318,13 +1434,13 @@ void ncplane_move_bottom(ncplane* n){
     if( (n->below->above = n->above) ){
       n->above->below = n->below;
     }else{
-      ncplane_notcurses(n)->top = n->below;
+      ncplane_pile(n)->top = n->below;
     }
     n->below = NULL;
-    if( (n->above = ncplane_notcurses(n)->bottom) ){
+    if( (n->above = ncplane_pile(n)->bottom) ){
       n->above->below = n;
     }
-    ncplane_notcurses(n)->bottom = n;
+    ncplane_pile(n)->bottom = n;
   }
 }
 
@@ -1508,6 +1624,7 @@ unsigned notcurses_supported_styles(const notcurses* nc){
   styles |= nc->tcache.dim ? NCSTYLE_DIM : 0;
   styles |= nc->tcache.bold ? NCSTYLE_BOLD : 0;
   styles |= nc->tcache.italics ? NCSTYLE_ITALIC : 0;
+  styles |= nc->tcache.struck ? NCSTYLE_STRUCK : 0;
   return styles;
 }
 
@@ -1865,10 +1982,16 @@ int ncplane_move_yx(ncplane* n, int y, int x){
 }
 
 int ncplane_y(const ncplane* n){
+  if(n->boundto == n){
+    return n->absy - ncplane_notcurses_const(n)->margin_t;
+  }
   return n->absy - n->boundto->absy;
 }
 
 int ncplane_x(const ncplane* n){
+  if(n->boundto == n){
+    return n->absx - ncplane_notcurses_const(n)->margin_t;
+  }
   return n->absx - n->boundto->absx;
 }
 
@@ -1898,11 +2021,11 @@ void ncplane_erase(ncplane* n){
 }
 
 ncplane* notcurses_top(notcurses* n){
-  return n->top;
+  return ncplane_pile(n->stdplane)->top;
 }
 
 ncplane* notcurses_bottom(notcurses* n){
-  return n->bottom;
+  return ncplane_pile(n->stdplane)->bottom;
 }
 
 ncplane* ncplane_below(ncplane* n){
@@ -2021,11 +2144,11 @@ void ncplane_translate(const ncplane* src, const ncplane* dst,
 }
 
 notcurses* ncplane_notcurses(ncplane* n){
-  return n->nc;
+  return ncplane_pile(n)->nc;
 }
 
 const notcurses* ncplane_notcurses_const(const ncplane* n){
-  return n->nc;
+  return ncplane_pile_const(n)->nc;
 }
 
 ncplane* ncplane_parent(ncplane* n){
@@ -2059,38 +2182,115 @@ int ncplane_resize_realign(ncplane* n){
 }
 
 // The standard plane cannot be reparented; we return NULL in that case.
-// If provided a NULL |newparent|, we are moving |n| to its own stack. If |n|
-// is already root of its own stack in this case, we return NULL. If |n| is
-// already bound to |newparent|, this is a no-op, and we return |n|.
+// If provided |newparent|==|n|, we are moving |n| to its own stack. If |n|
+// is already bound to |newparent|, this is a no-op, and we return |n|.
 ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
   if(n == ncplane_notcurses(n)->stdplane){
     return NULL; // can't reparent standard plane
   }
-  if(n->boundto == n && newparent == NULL){
-    return NULL; // can't make new stack out of a stack's root
-  }
-  if(newparent == NULL){ // FIXME make a new stack
-    newparent = ncplane_notcurses(n)->stdplane;
-  }
   if(n->boundto == newparent){
     return n;
   }
-  if(n->bprev){
+  if(n->boundto == n){ // children become new root planes
+    for(ncplane* child = n->blist ; child ; child = child->bnext){
+      child->boundto = child;
+    }
+  }else{ // children are rebound to current parent
+    if(n->blist){
+      if( (n->blist->bnext = n->boundto->blist) ){
+        n->boundto->blist->bprev = &n->blist->bnext;
+      }
+      n->blist->bprev = &n->boundto->blist;
+      n->boundto->blist = n->blist;
+      n->blist = NULL;
+    }
+  }
+  return ncplane_reparent_family(n, newparent);
+}
+
+// unsplice self from the z-axis, and then unsplice all children, recursively.
+// to be called before unbinding 'n' from old pile.
+static void
+unsplice_zaxis_recursive(ncplane* n){
+  if(ncplane_pile(n)->top == n){
+    ncplane_pile(n)->top = n->below;
+  }else{
+    n->above->below = n->below;
+  }
+  if(ncplane_pile(n)->bottom == n){
+    ncplane_pile(n)->bottom = n->above;
+  }else{
+    n->below->above = n->above;
+  }
+  for(ncplane* child = n->blist ; child ; child = child->bnext){
+    unsplice_zaxis_recursive(child);
+  }
+}
+
+// recursively splice 'n' and children into the z-axis, above 'n->boundto'.
+// handles 'n' == 'n->boundto'. to be called after binding 'n' into new pile.
+static void
+splice_zaxis_recursive(ncplane* n){
+  if(n != n->boundto){
+    if((n->above = n->boundto->above) == NULL){
+      n->pile->top = n;
+    }else{
+      n->boundto->above->below = n;
+    }
+    n->below = n->boundto;
+    n->boundto->above = n;
+  }
+  for(ncplane* child = n->blist ; child ; child = child->bnext){
+    splice_zaxis_recursive(child);
+  }
+}
+
+ncplane* ncplane_reparent_family(ncplane* n, ncplane* newparent){
+  if(n == ncplane_notcurses(n)->stdplane){
+    return NULL; // can't reparent standard plane
+  }
+  if(n->boundto == newparent){ // no-op
+    return n;
+  }
+  // if we are not a root plane, adjust our origin
+  if(n->boundto != n){
+    n->absx -= n->boundto->absx;
+    n->absy -= n->boundto->absy;
+  }
+  if(n->bprev){ // extract from sibling list
     if( (*n->bprev = n->bnext) ){
       n->bnext->bprev = n->bprev;
     }
   }
+  // if leaving a pile, extract n from the old zaxis
+  if(n == newparent || ncplane_pile(n) != ncplane_pile(newparent)){
+    unsplice_zaxis_recursive(n);
+  }
   n->boundto = newparent;
-  if(newparent == NULL){
+  if(n == n->boundto){ // we're a new root plane
     n->bnext = NULL;
     n->bprev = NULL;
-    return n;
+    pthread_mutex_lock(&ncplane_notcurses(n)->pilelock);
+    if(ncplane_pile(n)->top == NULL){ // did we just empty our pile?
+      ncpile_destroy(ncplane_pile(n));
+    }
+    make_ncpile(ncplane_notcurses(n), n);
+    pthread_mutex_unlock(&ncplane_notcurses(n)->pilelock);
+    splice_zaxis_recursive(n);
+  }else{ // establish ourselves as a sibling of new parent's children
+    n->absx += n->boundto->absx;
+    n->absy += n->boundto->absy;
+    if( (n->bnext = newparent->blist) ){
+      n->bnext->bprev = &n->bnext;
+    }
+    n->bprev = &newparent->blist;
+    newparent->blist = n;
+    // place it immediately above the new binding plane if crossing piles
+    if(n->pile != ncplane_pile(n->boundto)){
+      n->pile = ncplane_pile(n->boundto);
+      splice_zaxis_recursive(n);
+    }
   }
-  if( (n->bnext = newparent->blist) ){
-    n->bnext->bprev = &n->bnext;
-  }
-  n->bprev = &newparent->blist;
-  newparent->blist = n;
   return n;
 }
 
