@@ -130,6 +130,7 @@ int interrogate_terminfo(tinfo* ti){
     if(nocolor_stylemask & WA_ITALIC){
       ti->italics = NULL;
     }
+    // can't do anything about struck! :/
   }
   terminfostr(&ti->getm, "getm"); // get mouse events
   // Not all terminals support setting the fore/background independently
@@ -144,5 +145,9 @@ int interrogate_terminfo(tinfo* ti){
       return -1;
     }
   }
+  // some control sequences are unavailable from terminfo, and we must instead
+  // hardcode them :/. use at your own peril!
+  ti->struck = "\x1b[9m";
+  ti->struckoff = "\x1b[29m";
   return 0;
 }
