@@ -417,6 +417,38 @@ TEST_CASE("NCPlane") {
     CHECK(0 == ncplane_destroy(ncp));
   }
 
+  // create a new plane, the same size as the terminal, and verify that it
+  // occupies the same dimensions as the standard plane, but on another pile.
+  SUBCASE("NewPileSameSize") {
+    int x, y;
+    notcurses_term_dim_yx(nc_, &y, &x);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = y,
+      .cols = x,
+      nullptr, nullptr, nullptr, 0,
+    };
+    struct ncplane* ncp = ncpile_create(nc_, &nopts);
+    REQUIRE(ncp);
+    int px, py;
+    ncplane_dim_yx(ncp, &py, &px);
+    CHECK(y == py);
+    CHECK(x == px);
+    int sx, sy;
+    ncplane_dim_yx(n_, &sy, &sx);
+    CHECK(sy == py);
+    CHECK(sx == px);
+    // ensure that the new plane is not on our zaxis
+    CHECK(notcurses_top(nc_) == n_);
+    CHECK(notcurses_bottom(nc_) == n_);
+    // ensure the new plane has null above and below, and is bound to itself
+    CHECK(ncplane_above(ncp) == nullptr);
+    CHECK(ncplane_below(ncp) == nullptr);
+    CHECK(ncplane_parent_const(ncp) == ncp);
+    CHECK(0 == ncplane_destroy(ncp));
+  }
+
   SUBCASE("ShrinkPlane") {
     int maxx, maxy;
     int x = 0, y = 0;
@@ -519,6 +551,7 @@ TEST_CASE("NCPlane") {
     CHECK(0 == testcell.gcluster);
     CHECK(0 == testcell.stylemask);
     CHECK(0 == testcell.channels);
+    cell_release(n_, &testcell);
     int dimy, dimx;
     ncplane_dim_yx(n_, &dimy, &dimx);
     REQUIRE(0 == ncplane_cursor_move_yx(n_, 1, dimx - strlen(STR2)));
@@ -556,6 +589,7 @@ TEST_CASE("NCPlane") {
     CHECK(0 == testcell.gcluster);
     CHECK(0 == testcell.stylemask);
     CHECK(0 == testcell.channels);
+    cell_release(n_, &testcell);
     int dimy, dimx;
     ncplane_dim_yx(n_, &dimy, &dimx);
     REQUIRE(0 == ncplane_cursor_move_yx(n_, 1, dimx - mbstowcs(nullptr, STR2, 0)));
@@ -724,6 +758,7 @@ TEST_CASE("NCPlane") {
     // FIXME verify with ncplane_at_cursor_cell()
     CHECK(0 == ncplane_destroy(ncp));
   }
+
   SUBCASE("MoveToLowerRight") {
     int ncols, nrows;
     ncplane_dim_yx(n_, &nrows, &ncols);
@@ -864,25 +899,29 @@ TEST_CASE("NCPlane") {
       .x = 1,
       .rows = 2,
       .cols = 2,
-      nullptr, nullptr, nullptr, 0,
+      nullptr, "ndom", nullptr, 0,
     };
     struct ncplane* ndom = ncplane_create(n_, &nopts);
+    CHECK(ncplane_pile(ndom) == ncplane_pile(n_));
     REQUIRE(ndom);
+    nopts.name = "sub";
     struct ncplane* nsub = ncplane_create(ndom, &nopts);
+    CHECK(ncplane_pile(nsub) == ncplane_pile(ndom));
     REQUIRE(nsub);
     int absy, absx;
     CHECK(0 == notcurses_render(nc_));
     ncplane_yx(nsub, &absy, &absx);
     CHECK(1 == absy); // actually at 2, 2
     CHECK(1 == absx);
-    ncplane_reparent(nsub, nullptr);
+    ncplane_reparent(nsub, nsub);
+    CHECK(ncplane_pile(nsub) != ncplane_pile(ndom));
     ncplane_yx(nsub, &absy, &absx);
-    CHECK(2 == absy); // now we recognize 2, 2
-    CHECK(2 == absx);
+    CHECK(1 == absy); // now truly at 1, 1
+    CHECK(1 == absx);
     CHECK(0 == ncplane_move_yx(ndom, 0, 0));
     ncplane_yx(nsub, &absy, &absx);
-    CHECK(2 == absy); // still at 2, 2
-    CHECK(2 == absx);
+    CHECK(1 == absy); // still at 1, 1
+    CHECK(1 == absx);
   }
 
   SUBCASE("NoReparentStdPlane") {
