@@ -14,7 +14,17 @@ TEST_CASE("Readers") {
 
   SUBCASE("ReaderRender") {
     ncreader_options opts{};
-    auto ncp = ncplane_new(notcurses_stdplane(nc_), dimy / 2, dimx / 2, 0, 0, nullptr, nullptr);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = dimy / 2,
+      .cols = dimx / 2,
+      .userptr = nullptr,
+      .name = nullptr,
+      .resizecb = nullptr,
+      .flags = 0,
+    };
+    auto ncp = ncplane_create(notcurses_stdplane(nc_), &nopts);
     uint64_t echannels = CHANNELS_RGB_INITIALIZER(0xff, 0x44, 0xff, 0, 0, 0);
     ncplane_set_base(ncp, enforce_utf8() ? strdup("▒") : strdup("x"), 0, echannels);
     auto nr = ncreader_create(ncp, &opts);
